@@ -84,5 +84,5 @@ def load(brick):
 # def remove(brick):
 #     global library, config, bricks
 
-# def lsbricks():
-#     print(bricks)
+def listbricks():
+    print(bricks)
